@@ -43,7 +43,6 @@ TODO
 - make more tests
 - try to improve dynamic inventory
 - improve logging
-
 - improve DictToInventory mapper, so more options are possible
 
 """
@@ -139,11 +138,12 @@ class Ansiblator(object):
     Get started
     ===========
 
-    For instalation you can download package and then just unpack and use
+    For instalation you can download package and then just unpack package from
+    https://pypi.python.org/pypi/ansiblator and use it::
 
         python setup.py install
 
-    or
+    or install by pip::
 
         pip install ansiblator
 
@@ -170,7 +170,7 @@ class Ansiblator(object):
 
         ans = Ansiblator(inventory="/tmp/ansible_file", pattern="pc")
 
-    use dictionary to create ::
+    use dictionary to create inventory::
 
         inv = {'pc':[{'ssh_host':'192.168.0.10', 'ssh_user':'test_user', 'su_user':'root'},
                     {'ssh_host':'192.168.0.12', 'ssh_user':'test_user2', 'su_pass':'paasswd','su_user':'root'}]}
@@ -204,6 +204,16 @@ class Ansiblator(object):
         return_code = ans.local(["uname", "-a"], now=True, use_shell=False)
         return_code['contacted']
 
+    TODO
+    ====
+
+    - improve fabric-like api for more improvments
+    - make more tests
+    - try to improve dynamic inventory attachments
+    - make automatic translating of methods to ansible modules
+    - improve logging
+    - improve DictToInventory mapper, so more options are possible, such as groups and so on
+
     Info
     ====
     For more information you can consult functions or actual Ansible documentation.
@@ -409,7 +419,7 @@ class Ansiblator(object):
                 ret_code = runner.run()
             self.parse_ret_code(ret_code)
             self.ret_codes.append(ret_code)
-            # log.info(ret_code)
+            log.info(ret_code)
             return ret_code
         else:
             self.runners.append(runner)
